@@ -2,6 +2,7 @@ from typing import List, Optional
 
 import attr
 from marshmallow_annotations.ext.attrs import AttrsSchema
+from secoda_common.models.query import Query
 from secoda_common.models.tag import Tag
 from secoda_common.models.user import User
 
@@ -190,6 +191,7 @@ class Table:
     total_usage: Optional[int] = None
     unique_usage: Optional[int] = None
     quality: Optional[str] = None
+    queries: Optional[List[Query]] = []
 
 
 class TableSchema(AttrsSchema):
